@@ -16,10 +16,10 @@ include/dev.h - Supply file for dev_t encoding
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef RPL_DEV_H
 #define RPL_DEV_H 1
@@ -54,4 +54,4 @@ include/dev.h - Supply file for dev_t encoding
 
 #endif // RPL_DEV_H
 
-//==[ End of file ]============================================================
+//=============================================================================
