@@ -16,10 +16,10 @@ include/global.h - Shared definitions for user-space apps
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef TTYRPLD_GLOBAL_H
 #define TTYRPLD_GLOBAL_H 1
@@ -36,7 +36,7 @@ include/global.h - Shared definitions for user-space apps
 #define _(s) gettext(s)
 
 #define MAXFNLEN 256
-#define TTYRPLD_VERSION "2.00"
+#define TTYRPLD_VERSION "2.01"
 #if defined(__FreeBSD__) || defined(__OpenBSD__)
 #    define D_IOCTL(fd, cmd, eax) (ioctl((fd), (cmd), &(eax)) == 0)
 #else
@@ -55,4 +55,4 @@ inline static unsigned int min_uint(unsigned int a, unsigned int b) {
 
 #endif // TTYRPLD_GLOBAL_H
 
-//==[ End of file ]============================================================
+//=============================================================================
