@@ -16,10 +16,10 @@ include/pctrl.h
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef TTYREPLAY_PCTRL_H
 #define TTYREPLAY_PCTRL_H 1
@@ -47,4 +47,4 @@ extern void pctrl_deactivate(int);
 
 #endif // TTYREPLAY_PCTRL_H
 
-//==[ End of file ]============================================================
+//=============================================================================
