@@ -16,10 +16,10 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef TTYRPLD_RDSH_H
 #define TTYRPLD_RDSH_H 1
@@ -28,12 +28,12 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include "rpl_stdint.h"
 #include <libHX.h>
-#if !defined(_LIBHX_H) || _LIBHX_H < 20050206
-#    error --------------------------------------
+#if !defined(_LIBHX_H) || _LIBHX_H < 20050525
+#    error ----------------------------------------
 #    error You need a newer version of libHX
-#    error (at least 0_3-20050206)
-#    error http:/jengelh.hopto.org/prog-libHX.php
-#    error --------------------------------------
+#    error (at least 1.5.0 / 0_5-20050525)
+#    error http:/jengelh.hopto.org/coding/libHX.php
+#    error ----------------------------------------
 #endif
 
 #define RECEIVE_FULL(fd, ptr, sz) \
@@ -91,4 +91,4 @@ extern ssize_t send_wait(int, const void *, size_t, int);
 
 #endif // TTYRPLD_RDSH_H
 
-//==[ End of file ]============================================================
+//=============================================================================
