@@ -16,10 +16,10 @@ include/rpl_packet.h - Packet definitions for RPLD and RPLDEV
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef RPL_PACKET_H
 #define RPL_PACKET_H 1
@@ -67,4 +67,4 @@ struct rpldsk_packet {
 
 #endif // RPL_PACKET_H
 
-//==[ End of file ]============================================================
+//=============================================================================
