@@ -16,10 +16,10 @@ include/rpl_stdint.h - STDINT wrapper
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef RPL_STDINT_H
 #define RPL_STDINT_H 1
@@ -32,4 +32,4 @@ include/rpl_stdint.h - STDINT wrapper
 
 #endif // RPL_STDINT_H
 
-//==[ End of file ]============================================================
+//=============================================================================
