@@ -16,10 +16,10 @@ kernel/rpldev.c - Kernel interface for RPLD
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <asm/byteorder.h>
 #include <asm/semaphore.h>
@@ -77,23 +77,23 @@ kernel/rpldev.c - Kernel interface for RPLD
 #define SKIP_PTM(tty) if(IS_PTY_MASTER(tty)) { return 0; }
 
 // Stage 2 functions
-static int kio_init(struct tty_struct *, struct tty_struct *, struct file *);
-static int kio_open(struct tty_struct *, struct tty_struct *, struct file *);
-static int kio_read(const char __user *, size_t, struct tty_struct *);
-static int kio_write(const char __user *, size_t, struct tty_struct *);
-/*static int kio_ioctl(struct tty_struct *, struct tty_struct *, unsigned int,
+static int krpl_init(struct tty_struct *, struct tty_struct *, struct file *);
+static int krpl_open(struct tty_struct *, struct tty_struct *, struct file *);
+static int krpl_read(const char __user *, size_t, struct tty_struct *);
+static int krpl_write(const char __user *, size_t, struct tty_struct *);
+/*static int krpl_ioctl(struct tty_struct *, struct tty_struct *, unsigned int,
   unsigned long);*/
-static int kio_close(struct tty_struct *, struct tty_struct *);
-static int kio_deinit(struct tty_struct *, struct tty_struct *);
+static int krpl_close(struct tty_struct *, struct tty_struct *);
+static int krpl_deinit(struct tty_struct *, struct tty_struct *);
 
 // Stage 3 functions
-static int uio_open(struct inode *, struct file *);
-static ssize_t uio_read(struct file *, char __user *, size_t, loff_t *);
-static loff_t uio_seek(struct file *, loff_t, int);
-static int uio_ioctl(struct inode *, struct file *, unsigned int,
-  unsigned long);
-static unsigned int uio_poll(struct file *, poll_table *);
-static int uio_close(struct inode *, struct file *);
+static int     urpl_open(struct inode *, struct file *);
+static ssize_t urpl_read(struct file *, char __user *, size_t, loff_t *);
+static loff_t  urpl_seek(struct file *, loff_t, int);
+static int     urpl_ioctl(struct inode *, struct file *, unsigned int,
+                          unsigned long);
+static unsigned int urpl_poll(struct file *, poll_table *);
+static int          urpl_close(struct inode *, struct file *);
 
 // Local functions
 inline static ssize_t avail_R(void);
@@ -115,12 +115,12 @@ static int Minor_nr = MISC_DYNAMIC_MINOR, Open_count = 0;
 
 // Kernel module info (kmi) stuff
 static struct file_operations kmi_fops = {
-    .open    = uio_open,
-    .read    = uio_read,
-    .llseek  = uio_seek,
-    .ioctl   = uio_ioctl,
-    .poll    = uio_poll,
-    .release = uio_close,
+    .open    = urpl_open,
+    .read    = urpl_read,
+    .llseek  = urpl_seek,
+    .ioctl   = urpl_ioctl,
+    .poll    = urpl_poll,
+    .release = urpl_close,
     .owner   = THIS_MODULE,
 };
 static struct miscdevice kmi_miscinfo = {
@@ -163,7 +163,7 @@ __exit void cleanup_module(void) {
 }
 
 //-----------------------------------------------------------------------------
-static int kio_init(struct tty_struct *tty, struct tty_struct *ctl,
+static int krpl_init(struct tty_struct *tty, struct tty_struct *ctl,
  struct file *filp)
 {
     /* Called from drivers/char/tty_io.c:init_dev() when the refcount of a tty
@@ -187,7 +187,7 @@ static int kio_init(struct tty_struct *tty, struct tty_struct *ctl,
     return mv_buffer(&p, full_dev, len);
 }
 
-static int kio_open(struct tty_struct *tty, struct tty_struct *ctl,
+static int krpl_open(struct tty_struct *tty, struct tty_struct *ctl,
  struct file *filp)
 {
     /* Called from drivers/char/tty_io.c:tty_open() whenever an open() on a
@@ -211,10 +211,10 @@ static int kio_open(struct tty_struct *tty, struct tty_struct *ctl,
     return mv_buffer(&p, full_dev, len);
 }
 
-static int kio_read(const char __user *buf, size_t count,
+static int krpl_read(const char __user *buf, size_t count,
  struct tty_struct *tty)
 {
-    /* The data flow is a bit weird at first. kio_read() gets the data on its
+    /* The data flow is a bit weird at first. krpl_read() gets the data on its
     way between ttyDriver(master) -> /dev/stdin(slave), meaning this function
     is called when you hit the keyboard. _Even_ if you do not see any text
     onscreen. */
@@ -231,7 +231,7 @@ static int kio_read(const char __user *buf, size_t count,
     return mv_buffer(&p, buf, count);
 }
 
-static int kio_write(const char __user *buf, size_t count,
+static int krpl_write(const char __user *buf, size_t count,
  struct tty_struct *tty)
 {
     /* Data flow: /dev/stdout(slave) -> tty driver(master).
@@ -263,7 +263,7 @@ static int kio_write(const char __user *buf, size_t count,
 }
 
 /*
-static int kio_ioctl(struct tty_struct *tty, struct tty_struct *ctl,
+static int krpl_ioctl(struct tty_struct *tty, struct tty_struct *ctl,
  unsigned int cmd, unsigned long arg)
 {
     struct rpld_packet p;
@@ -281,7 +281,7 @@ static int kio_ioctl(struct tty_struct *tty, struct tty_struct *ctl,
 }
 */
 
-static int kio_close(struct tty_struct *tty, struct tty_struct *other) {
+static int krpl_close(struct tty_struct *tty, struct tty_struct *other) {
     struct rpldev_packet p;
 
     SKIP_PTM(tty);
@@ -294,7 +294,7 @@ static int kio_close(struct tty_struct *tty, struct tty_struct *other) {
     return mv_buffer(&p, NULL, 0);
 }
 
-static int kio_deinit(struct tty_struct *tty, struct tty_struct *other) {
+static int krpl_deinit(struct tty_struct *tty, struct tty_struct *other) {
     struct rpldev_packet p;
 
     if(IS_PTY_MASTER(tty)) { tty = other; }
@@ -308,7 +308,7 @@ static int kio_deinit(struct tty_struct *tty, struct tty_struct *other) {
 }
 
 //-----------------------------------------------------------------------------
-static int uio_open(struct inode *inode, struct file *filp) {
+static int urpl_open(struct inode *inode, struct file *filp) {
     // This one is called when the device node has been opened.
     if(inode != NULL) {
         inode->i_mtime = CURRENT_TIME;
@@ -336,13 +336,13 @@ static int uio_open(struct inode *inode, struct file *filp) {
 
     /* Update links. I do it here 'cause I do not want memory copying (from the
     tty driver to the buffer) when there is no one to read. */
-    rpl_qinit   = kio_init;
-    rpl_qopen   = kio_open;
-    rpl_qread   = kio_read;
-    rpl_qwrite  = kio_write;
-    //rpl_qioctl  = kio_ioctl;
-    rpl_qclose  = kio_close;
-    rpl_qdeinit = kio_deinit;
+    rpl_qinit   = krpl_init;
+    rpl_qopen   = krpl_open;
+    rpl_qread   = krpl_read;
+    rpl_qwrite  = krpl_write;
+    //rpl_qioctl  = krpl_ioctl;
+    rpl_qclose  = krpl_close;
+    rpl_qdeinit = krpl_deinit;
     up(&Buffer_lock);
 
     /* The inode's times are changed as follows:
@@ -354,8 +354,8 @@ static int uio_open(struct inode *inode, struct file *filp) {
     return 0;
 }
 
-static ssize_t uio_read(struct file *filp, char __user *buf,
- size_t count, loff_t *ppos)
+static ssize_t urpl_read(struct file *filp, char __user *buf, size_t count,
+ loff_t *ppos)
 {
     // Nothing read, nothing done
     if(count == 0) { return 0; }
@@ -380,7 +380,7 @@ static ssize_t uio_read(struct file *filp, char __user *buf,
     return count;
 }
 
-static loff_t uio_seek(struct file *filp, loff_t offset, int origin) {
+static loff_t urpl_seek(struct file *filp, loff_t offset, int origin) {
     /* Since you can not seek in the circular buffer, the only purpose of
     seek() is to skip some bytes and "manually" advance the read pointer RP
     (BufRP). Thus, the only accepted origin is SEEK_CUR, or SEEK_END
@@ -409,7 +409,7 @@ static loff_t uio_seek(struct file *filp, loff_t offset, int origin) {
     return 0;
 }
 
-static int uio_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
+static int urpl_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
  unsigned long arg)
 {
     if(_IOC_TYPE(cmd) != RPL_IOC_MAGIC) { return -ENOTTY; /* ENAUGHTY */ }
@@ -423,19 +423,19 @@ static int uio_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
         case RPL_IOC_IDENTIFY:
             return 0xC0FFEE;
         case RPL_IOC_SEEK:
-            return uio_seek(filp, arg, SEEK_CUR);
+            return urpl_seek(filp, arg, SEEK_CUR);
         case RPL_IOC_FLUSH:
-            return uio_seek(filp, 0, SEEK_END);
+            return urpl_seek(filp, 0, SEEK_END);
     }
     return -ENOTTY;
 }
 
-static unsigned int uio_poll(struct file *filp, poll_table *wait) {
+static unsigned int urpl_poll(struct file *filp, poll_table *wait) {
     poll_wait(filp, &Pull_queue, wait);
     return POLLIN | POLLRDNORM;
 }
 
-static int uio_close(struct inode *inode, struct file *filp) {
+static int urpl_close(struct inode *inode, struct file *filp) {
     rpl_qinit   = NULL;
     rpl_qopen   = NULL;
     rpl_qread   = NULL;
@@ -551,4 +551,4 @@ inline static void mv_to_user(char __user *dest, size_t count) {
     return;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
