@@ -16,10 +16,10 @@ user/global.c - Shared functions for user-space apps
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/ioctl.h>
 #include <sys/stat.h>
@@ -55,7 +55,10 @@ void load_locale(const char *exe) {
         hmc_strcat(&base, "/locale");
         de = hmc_dup(base);
         hmc_strcat(&de, "/de/LC_MESSAGES/ttyrpld.mo");
-        if(stat(de, &sb) == 0) { bindtextdomain("ttyrpld", base); ++ok; }
+        if(stat(de, &sb) == 0) {
+            bindtextdomain("ttyrpld", base);
+            ++ok;
+        }
         hmc_free(base);
         hmc_free(de);
     }
@@ -63,11 +66,9 @@ void load_locale(const char *exe) {
     if(!ok) {
         if(stat("locale/de/LC_MESSAGES/ttyrpld.mo", &sb) == 0) {
             bindtextdomain("ttyrpld", ".");
-        } else if(stat("/usr/local/share/locale/de/LC_MESSAGES/ttyrpld.mo",
-         &sb) == 0) {
+        } else if(stat("/usr/local/share/locale/de/LC_MESSAGES/ttyrpld.mo", &sb) == 0) {
             bindtextdomain("ttyrpld", "/usr/local/share/locale");
-        } else if(stat("/usr/share/locale/de/LC_MESSAGES/ttyrpld.mo",
-         &sb) == 0) {
+        } else if(stat("/usr/share/locale/de/LC_MESSAGES/ttyrpld.mo", &sb) == 0) {
             bindtextdomain("ttyrpld", "/usr/share/locale");
         }
     }
@@ -153,4 +154,4 @@ void swab_be(void *srcp, size_t count) {
     return;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
