@@ -16,10 +16,10 @@ user/infod.c - INFO socket for RPLD
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -259,7 +259,9 @@ inline static const char *basename_pp(const char *s, const char *t) {
     if(s == NULL) { return NULL; }
 
     if((p = strchr(t, '%')) != NULL) {
-        if((p = HX_strbchr(t, p, '/')) != NULL) { return s + (p - t) + 1; }
+        if((p = HX_strbchr(t, p, '/')) != NULL) {
+            return s + (p - t) + 1;
+        }
     } else if((p = strrchr(s, '/')) != NULL) {
         return p + 1;
     }
@@ -333,4 +335,4 @@ static int unix_server(const char *port) {
     return fd;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
