@@ -16,10 +16,10 @@ user/pctrl.c - "Remote control" for ttyreplay
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/select.h>
@@ -159,4 +159,4 @@ void pctrl_deactivate(int sig) {
     return;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
