@@ -16,10 +16,10 @@ user/rdsh.c - Shared functions for RPLD/INFOD/RPLCTL
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -156,4 +156,4 @@ static void setup_kversion(void) {
     return;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
