@@ -16,10 +16,10 @@ user/replay.c - Realtime TTY log analyzer
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/stat.h>
 #include <sys/time.h> // usec def, gettimeofday()
@@ -96,10 +96,10 @@ int main(int argc, const char **argv) {
 
     fprintf(stderr, "> ttyreplay " TTYRPLD_VERSION "\n");
     fprintf(stderr,
-      _("This program comes with ABSOLUTELY NO WARRANTY; it is free "
-      "software\n" "and you are welcome to redistribute it under certain "
-      "conditions; for\n" "details see the COPYING file which should have "
-      "come with this program.\n")
+      _("This program comes with ABSOLUTELY NO WARRANTY; it is free"
+      " software\n" "and you are welcome to redistribute it under certain"
+      " conditions; for\n" "details see the \"LICENSE\" file which should"
+      " have come with this program.\n")
     );
 
     if(argc == 0) {
@@ -709,4 +709,4 @@ inline static void usec2tv(unsigned long long usec, struct timeval *req) {
     return;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
