@@ -16,10 +16,10 @@ user/rplctl.c - INFOD client
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/select.h>
@@ -268,4 +268,4 @@ static int get_options(int *argc, const char ***argv) {
     return got;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
