@@ -16,10 +16,10 @@ user/rpld.c - User space daemon (filtering, etc.)
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-  02111-1307, USA.
+  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+  Boston, MA 02111-1307, USA.
 
-  -- For details see the COPYING file
+  -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/mman.h> // mlock()
@@ -83,7 +83,7 @@ static void sighandler_pipe(int);
 static int get_options(int *, const char ***);
 static int read_config(const char *);
 static int read_config_bp(const char *, const char *);
-static int pconfig_user(const char *, unsigned char, void *, void *);
+static int pconfig_user(const struct shconf_opt *, const char *);
 
 inline static const char *basename(const char *);
 static int find_devnode(uint32_t, char *, size_t, const char **);
@@ -135,14 +135,14 @@ int main(int argc, const char **argv) {
 
     if(GOpt.verbose) {
         printf("# rpld " TTYRPLD_VERSION "\n");
-        printf(_("This program comes with ABSOLUTELY NO WARRANTY; it is free "
-          "software\n" "and you are welcome to redistribute it under certain "
-          "conditions; for\n" "details see the COPYING file which should have "
-          "come with this program.\n")
+        printf(_("This program comes with ABSOLUTELY NO WARRANTY; it is free"
+          " software\n" "and you are welcome to redistribute it under certain"
+          " conditions; for\n" "details see the \"LICENSE\" file which should"
+          " have come with this program.\n")
         );
     }
 
-    if((Ttys = HXbtree_init(HXBT_MAP | HXBT_ICMP | HXBT_NCID)) == NULL) {
+    if((Ttys = HXbtree_init(HXBT_MAP | HXBT_ICMP)) == NULL) {
         perror("Ttys = HXbtree_init()");
         return EXIT_FAILURE;
     }
@@ -650,7 +650,7 @@ static int get_options(int *argc, const char ***argv) {
                 Opt.dolog = 0;
                 break;
             case 'U':
-                if(!pconfig_user(NULL, 0, tmp, NULL)) { return 0; }
+                if(!pconfig_user(NULL, tmp)) { return 0; }
                 free(tmp);
                 break;
             case 'c':
@@ -679,17 +679,17 @@ static int get_options(int *argc, const char ***argv) {
 }
 
 static int read_config(const char *file) {
-    static struct rconfig_opt options_table[] = {
-        {"DEVICE", RCONF_STRING, &Opt.device, NULL},
-        {"OFMT",   RCONF_STRING, &GOpt.ofmt,  NULL},
-        {"DO_LOG", RCONF_IBOOL,  &Opt.dolog,  NULL},
-        {"USER",   RCONF_CB,     NULL,        pconfig_user},
+    static struct shconf_opt options_table[] = {
+        {"DEVICE", SHCONF_STRING, &Opt.device},
+        {"OFMT",   SHCONF_STRING, &GOpt.ofmt},
+        {"DO_LOG", SHCONF_IBOOL,  &Opt.dolog},
+        {"USER",   SHCONF_CB,     &GOpt.user_id, pconfig_user},
 
-        {"INFOD_PORT", RCONF_STRING, &GOpt.infod_port, NULL},
-        {"START_INFOD", RCONF_IBOOL, &Opt.infod_start, NULL},
+        {"INFOD_PORT", SHCONF_STRING, &GOpt.infod_port},
+        {"START_INFOD", SHCONF_IBOOL, &Opt.infod_start},
         {NULL},
     };
-    return HX_rconfig(file, options_table);
+    return HX_shconfig(file, options_table);
 }
 
 static int read_config_bp(const char *app_path, const char *file) {
@@ -705,10 +705,9 @@ static int read_config_bp(const char *app_path, const char *file) {
     return read_config(construct);
 }
 
-static int pconfig_user(const char *key, unsigned char type, void *ptr,
- void *uptr) {
-    if((GOpt.user_id = getuidfromname(ptr)) < 0) {
-        fprintf(stderr, _("No such user: %s\n"), (const char *)ptr);
+static int pconfig_user(const struct shconf_opt *t, const char *val) {
+    if((GOpt.user_id = getuidfromname(val)) < 0) {
+        fprintf(stderr, _("No such user: %s\n"), val);
         exit(EXIT_FAILURE);
     }
     return 1;
@@ -800,4 +799,4 @@ static uid_t getuidfromname(const char *name) {
     return ep->pw_uid;
 }
 
-//==[ End of file ]============================================================
+//=============================================================================
